# PyHelper - A packages that provide more helper tools for Python

[Chinese Version - 中文版本](README-chinese.md)

This is a Packages that provide more helper tools for Python

## Downloading packages

This package has not yet been published to PyPi(because the name is the same),
so the whl package must be downloaded and installed manually

To log in first [GitHub](https://github.com/), the [Pyhelper official website](https://github.com/pyhelper.git), and then find a ` ` ` Releases ` ` ` column,
Click on the distribution below.
![](assets/img.png)

Then under Assets, download pyhelper-2.1.0-py2.py3-none-any.whl. The name may vary from version to version, but it should end with.whl

![](assets/img_1.png)

Once the download is complete, switch to the directory containing the whl file and run pip3 install [Whl file], replacing [Whl file] with the name of the whl file you downloaded

*Note: If you need to install in a virtual environment, remember to activate the virtual environment in advance!*

And that's it!

## Ontribution

If you want to contribute to PyHelper, see https://github.com/nanocode38/pyhelper.git
